"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.BuildContest = exports.BuildProblemSet = exports.Build = void 0;
const leetcode_api_typescript_1 = require("leetcode-api-typescript");
const leetcode_api_typescript_2 = require("leetcode-api-typescript");
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const shelljs_1 = __importDefault(require("shelljs"));
const Constant = __importStar(require("./constant"));
function Build(name) {
    if (name === "problems") {
        return BuildProblemSet;
    }
    return BuildContest;
}
exports.Build = Build;
async function BuildProblemSet(src, dst, docsRelativePath) {
    const navList = [];
    const dirs = fs_1.default.readdirSync(src);
    dirs.sort((a, b) => {
        const _a = Number(a.split(".")[0]);
        const _b = Number(b.split(".")[0]);
        if (_a < _b) {
            return -1;
        }
        if (_a > _b) {
            return 1;
        }
        return 0;
    });
    for (const dir of dirs) {
        buildProblemContent(path_1.default.join(src, dir), path_1.default.join(dst, dir));
        navList.push({ [dir]: path_1.default.join(docsRelativePath, dir, "index.md") });
    }
    return navList;
}
exports.BuildProblemSet = BuildProblemSet;
async function BuildContest(src, dst, docsRelativePath) {
    const navList = [];
    const dirs = fs_1.default.readdirSync(src);
    dirs.sort((a, b) => {
        const _a = Number(a);
        const _b = Number(b);
        if (_a < _b)
            return -1;
        if (_a > _b)
            return 1;
        return 0;
    });
    for (const dir of dirs) {
        buildContestContent(path_1.default.join(src, dir), path_1.default.join(dst, dir));
        navList.push({ [dir]: path_1.default.join(docsRelativePath, dir, "index.md") });
    }
    return navList;
}
exports.BuildContest = BuildContest;
function buildProblemContent(src, dst) {
    const mdContent = `# ${src.split(path_1.default.sep).slice(-1)[0]}

${makeContent(src, dst, 2)}

`;
    fs_1.default.writeFileSync(path_1.default.join(dst, "index.md"), mdContent);
}
function buildContestContent(src, dst) {
    let mdContent = `# ${src.split(path_1.default.sep).slice(-2).join("-")}`;
    const dirs = fs_1.default.readdirSync(src);
    dirs.sort();
    for (const dir of dirs) {
        mdContent += `
## ${String.fromCharCode("A".charCodeAt(0) + (dir.charCodeAt(0) - "a".charCodeAt(0)))}

${makeContent(path_1.default.join(src, dir), path_1.default.join(dst, dir), 3)}

`;
        fs_1.default.writeFileSync(path_1.default.join(dst, "index.md"), mdContent);
    }
}
function makeContent(src, dst, tocBase) {
    return `
${makeStatementContent(src, dst, tocBase)}

${makeSolutionContent(src, dst, tocBase)}
`;
}
function makeStatementContent(src, dst, tocBase) {
    const statementContent = (() => {
        const getContent = (filename) => {
            if (!fs_1.default.existsSync(path_1.default.join(src, filename))) {
                return null;
            }
            return fs_1.default
                .readFileSync(path_1.default.join(src, filename))
                .toString()
                .replace(/<pre>/g, "<pre><code>")
                .replace(/<pre><code>\n/g, "<pre><code>")
                .replace(/<\/pre>/g, "</code></pre>")
                .replace(/\*/g, "\\*")
                .split("\n")
                .filter((s) => s !== "")
                .map((s) => "    " + s)
                .join("\n");
        };
        const statementContent = {
            en_US: getContent(Constant.StatementFileName.en_US),
            zh_CN: getContent(Constant.StatementFileName.zh_CN),
        };
        return statementContent;
    })();
    shelljs_1.default.rm("-R", `${dst}/problem-assets/problem.json`);
    shelljs_1.default.rm("-R", `${dst}/*.md`);
    const statementContentList = [];
    if (statementContent.zh_CN) {
        statementContentList.push(`
=== "简体中文"
${statementContent.zh_CN}
`);
    }
    if (statementContent.en_US) {
        statementContentList.push(`
=== "English"
${statementContent.en_US}
`);
    }
    if (statementContentList.length === 0) {
        return "";
    }
    return `
${"#".repeat(tocBase)} Statement

${statementContentList.join("\n")}

`;
}
function makeSolutionContent(src, dst, tocBase) {
    const tutorialName = "tutorial";
    const solutionName = "solution";
    const getIdx = (ix) => {
        if (ix === 0) {
            return "";
        }
        return ix.toString();
    };
    const solutionContentList = (() => {
        const solutionContentList = [];
        for (let i = 0;; i++) {
            let content = "";
            const tutorialFileName = `${tutorialName}${getIdx(i)}.md`;
            if (fs_1.default.existsSync(path_1.default.join(src, tutorialFileName))) {
                content += `
${"#".repeat(tocBase)} Tutorial${getIdx(i)}

--8<-- "${src}/${tutorialFileName}"

                `;
                fs_1.default.rmSync(path_1.default.join(dst, tutorialFileName));
            }
            let solutionContent = "";
            for (const slug of Object.values(leetcode_api_typescript_2.LangSlug)) {
                const ext = (0, leetcode_api_typescript_1.LangSlugExt)(slug);
                const solutionFileName = `${solutionName}${getIdx(i)}.${ext}`;
                if (fs_1.default.existsSync(path_1.default.join(src, solutionFileName))) {
                    solutionContent += `
=== "${leetcode_api_typescript_2.LangSlug[slug]}"
\`\`\`${ext}
--8<-- "${src}/${solutionFileName}"
\`\`\`
                    `;
                    fs_1.default.rmSync(path_1.default.join(dst, solutionFileName));
                }
            }
            if (solutionContent.length !== 0) {
                content += `
${"#".repeat(tocBase)} Solution${getIdx(i)}

${solutionContent}
                `;
            }
            if (content === "") {
                break;
            }
            solutionContentList.push(content);
        }
        return solutionContentList;
    })();
    if (solutionContentList.length === 0) {
        return "";
    }
    return solutionContentList.join("\n");
}
//# sourceMappingURL=mkdocs.js.map